@@ -22,32 +22,37 @@ import sys
 from pathlib import Path
 from typing import List
 
-from PyQt5.QtCore import pyqtSignal, QObject
-from PyQt5.QtWidgets import QAction
+from qtpy.QtCore import Signal, QObject
+from qtpy.QtWidgets import QAction
 
+import dpp
+from dpp.core import logger
 from dpp.core.listener import Listener
-from dpp.core.plugin import AbstractPlugin, Plugins
-from dpp.core.shortcut import Shortcut, NullShortcut
+from dpp.core.plugin import AbstractPlugin
+from dpp.core.plugin.manager import PluginManager
+from dpp.core.shortcuts import Shortcut, NullShortcut
 
 
 class Context(QObject):
     """
     The context of the application.
-    This includes often used functionality like logging, configuration and plugins.
+    Contains access to often used functionalities like logging, configuration and plugins.
     Interaction with this class should be limited to minimize dependencies.
     """
 
-    shortcutUpdated = pyqtSignal('PyQt_PyObject')
+    shortcutUpdated = Signal('PyQt_PyObject')
 
     class Mode:
-        """ A list of different application modes. """
-        GRAPHICAL_UI = "gfx" # graphical user interface
-        COMMAND_LINE = "cmd" # command shell
-        INTERACTIVE = "interactive" # Python Interactive Shell
+        GUI_MODERN = "gui-modern"
+        GUI_CLASSIC = "gui-classic"
+        COMMAND_LINE = "cmd"
+
+    class DockWidget:
+        EMPTY_DOCK_WIDGET = "empty_dock_widget"
+        LOG_DOCK_WIDGET = "log_dock_widget"
+        HEX_DOCK_WIDGET = "hex_dock_widget"
 
     class Shortcut:
-        """ A set of all shortcut ids which can be used within the application. """
-
         FILE_EXIT = "file_exit"
         EDIT_CUT = "edit_cut"
         EDIT_COPY = "edit_copy"
@@ -78,53 +83,41 @@ class Context(QObject):
         FOCUS_INPUT_TEXT = "focus_input_text"
         FOCUS_INPUT_TEXT_NEXT = "focus_input_text_next"
         FOCUS_INPUT_TEXT_PREVIOUS = "focus_input_text_previous"
-        SELECT_PLAIN_VIEW = "select_plain_view"
+        SELECT_MODERN_GUI = "select_modern_gui"
+        SELECT_CLASSIC_GUI = "select_classic_gui"
         SELECT_HEX_DOCK = "select_hex_dock"
         SELECT_LOG_DOCK = "select_log_dock"
         TOGGLE_SEARCH_FIELD = "toggle_search_field"
         SHOW_PLUGINS = "show_plugins"
+        SHOW_KEYBOARD_SHORTCUTS = "show_keyboard_shortcuts"
+        SHOW_ABOUT = "show_about"
 
     def __init__(self, app_id, app_path, namespace):
         super(__class__, self).__init__()
         self._app_id = app_id
         self._app_path = app_path
         self._namespace = namespace
-        self._logger = {}
-        self.config = self._init_config()
+        self._trace_mode = False
         self._debug_mode = self.config.isDebugModeEnabled()
+        self._logger = logger.init_logger(self.getLogLevel())
         self._listener = Listener(self)
-        self._plugins = Plugins([
-            os.path.join(self._app_path, "plugins"),
-            os.path.join(str(Path.home()), ".config", "dpp", "plugins")], self)
+        self._plugins = None
         self._shortcuts = {}
         self._installed_packages = []
         self._mode = None
 
-    def _init_config(self):
+    @property
+    def config(self):
         """ Returns the configuration. """
-        from dpp.core.config import Config
-        return Config()
+        if not hasattr(self, '_config') or not self._config:
+            from dpp.core.config import Config
+            self._config = Config()
+        return self._config
 
-    def _init_logger(self, log_format):
-        """ Returns the logger. """
-        logger = logging.getLogger(self._app_id)
-        log_level = logging.DEBUG if self.config.isDebugModeEnabled() else logging.WARN
-
-        logging.root.setLevel(log_level)
-        console_logger = logging.StreamHandler(sys.stderr)
-        console_logger.setFormatter(logging.Formatter(log_format))
-        logger.addHandler(console_logger)
-
-        if log_level == logging.DEBUG:
-            file_logger = logging.FileHandler(os.path.join(self.getAppPath(), "dpp.log"))
-            file_logger.setLevel(log_level)
-            file_logger_formatter = logging.Formatter(
-                '%(asctime)s - %(module)s: %(lineno)d: %(msg)s',
-                datefmt='%m/%d/%Y %I:%M:%S %p')
-            file_logger.setFormatter(file_logger_formatter)
-            logger.addHandler(file_logger)
-
-        return logger
+    @property
+    def logger(self) -> logging.Logger:
+        """ Returns the standard logger for this application. """
+        return logging.getLogger()
 
     def getAppName(self) -> str:
         """ Returns the name of the application. """
@@ -132,7 +125,7 @@ class Context(QObject):
 
     def getAppVersion(self) -> str:
         """ Returns the version of the application. """
-        return "1.0.0"
+        return dpp.__version__
 
     def getAppPath(self):
         """ Returns the path where the main application is located. """
@@ -150,14 +143,31 @@ class Context(QObject):
         """ :returns the mode (see ``Context.Mode``) the application is currently running in or None if unspecified. """
         return self._mode
 
+    def getLogLevel(self):
+        """ :returns the current log level. """
+        if self._trace_mode:
+            return logging.TRACE
+        if self._debug_mode or self.isDebugModeEnabled():
+            return logging.DEBUG
+        return logging.INFO
+
     def setDebugMode(self, status: bool, temporary=False):
         """ Enables/Disables debug mode. """
         if not temporary:
             self.config.setDebugMode(status)
         self._debug_mode = status
-        logging.root.setLevel(logging.DEBUG if status else logging.INFO)
+        self._trace_mode = False
+        logger.set_level(logging.DEBUG if status else logging.INFO)
         status_string = "enabled" if status else "disabled"
-        self.logger().info("Debug Mode: {} {}".format(status_string, " (temporary) " if temporary else ""))
+        self._logger.info("Debug Mode: {} {}".format(status_string, " (temporary) " if temporary else ""))
+
+    def setTraceMode(self, status: bool):
+        """ Enables/Disables debug mode. """
+        self._trace_mode = status
+        self._debug_mode = False
+        logger.set_level(logging.TRACE if status else logging.INFO)
+        status_string = 'enabled' if status else 'disabled'
+        self._logger.info(f'Trace Mode: {status_string}')
 
     def toggleDebugMode(self):
         """ Toggles the debug-mode on/off. """
@@ -177,16 +187,12 @@ class Context(QObject):
         """ Returns the listener instance which allows to subscribe to certain events. """
         return self._listener
 
-    def logger(self, log_format="%(module)s: %(lineno)d: %(msg)s", log_fields=None):
-        """ Returns the logger of the application. """
-        if log_format not in self._logger:
-            self._logger[log_format] = self._init_logger(log_format)
-        if log_fields:
-            return logging.LoggerAdapter(self._logger[log_format], log_fields)
-        return self._logger[log_format]
-
-    def plugins(self) -> Plugins:
+    def plugins(self) -> PluginManager:
         """ Returns all plugins. """
+        if not self._plugins:
+            self._plugins = PluginManager([
+                os.path.join(self._app_path, "plugins"),
+                os.path.join(str(Path.home()), ".config", "dpp", "plugins")], self)
         return self._plugins
 
     def checkDependency(self, package):
@@ -201,51 +207,56 @@ class Context(QObject):
             self._installed_packages = [r.decode().split('==')[0] for r in reqs.split()]
         return package in self._installed_packages
 
-    def registerShortcut(self, the_id: str, the_name: str, the_default_shortcut_key: str, the_callback, the_widget) -> QAction:
+    def registerShortcut(self, id: str, name: str, default_shortcut_key: str, callback, widget) -> QAction:
         """
         Registers a shortcut with the specified parameters.
-        :param the_id: the id of the shortcut.
-        :param the_name: the name of the shortcut which is displayed to the user.
-        :param the_default_shortcut_key: the default shortcut key which may be overwritten by the user.
-        :param the_callback: the callback which should be triggered when the shortcut is used.
-        :param the_widget: the widget to which the shortcut is bound to.
+        :param id: the id of the shortcut.
+        :param name: the name of the shortcut which is displayed to the user.
+        :param default_shortcut_key: the default shortcut key which may be overwritten by the user.
+        :param callback: the callback which should be triggered when the shortcut is used.
+        :param widget: the widget to which the shortcut is bound to.
         """
-        the_shortcut_key = self.config.getShortcutKey(the_id)
-        if not the_shortcut_key:
-            the_shortcut_key = the_default_shortcut_key
-        self.logger().debug("Registering shortcut {} to {}".format(the_id, the_shortcut_key))
-        shortcut = Shortcut(the_id, the_name, the_shortcut_key, the_callback, the_widget)
-        self._shortcuts[the_id] = shortcut
-        self.config.setShortcutKey(the_id, the_shortcut_key)
+        shortcut_key = self.config.getShortcutKey(id)
+        if not shortcut_key:
+            shortcut_key = default_shortcut_key
+
+        self._logger.trace("Registering shortcut {} to {}".format(id, shortcut_key))
+        if id in self._shortcuts:
+            self._logger.debug("Retrieving previously registered shortcut {}".format(id, shortcut_key))
+            return self._shortcuts[id].clone(name)
+
+        shortcut = Shortcut(id, name, shortcut_key, callback, widget)
+        self._shortcuts[id] = shortcut
+        self.config.setShortcutKey(id, shortcut_key)
         self.shortcutUpdated.emit(shortcut)
         return shortcut
 
-    def updateShortcutKey(self, the_id: str, the_shortcut_key: str):
+    def updateShortcutKey(self, id: str, shortcut_key: str):
         """
         Updates the shortcut with the specified id.
-        :param the_id: the id of the shortcut.
-        :param the_shortcut_key: the shortcut key which should be used onwards.
+        :param id: the id of the shortcut.
+        :param shortcut_key: the shortcut key which should be used onwards.
         """
-        if the_id not in self._shortcuts:
-            self.logger().error("Shortcut {} is not defined".format(the_id))
+        if id not in self._shortcuts:
+            self._logger.error("Shortcut {} is not defined".format(id))
             return
 
-        self.logger().debug("Updating shortcut {} to {}".format(the_id, the_shortcut_key))
-        shortcut = self._shortcuts[the_id]
-        shortcut.setKey(the_shortcut_key)
-        self.config.setShortcutKey(the_id, the_shortcut_key)
+        self._logger.debug("Updating shortcut {} to {}".format(id, shortcut_key))
+        shortcut = self._shortcuts[id]
+        shortcut.setKey(shortcut_key)
+        self.config.setShortcutKey(id, shortcut_key)
         self.shortcutUpdated.emit(shortcut)
 
     def getShortcuts(self) -> List[Shortcut]:
         """ Returns a list of shortcuts. """
         return self._shortcuts.values()
 
-    def getShortcutById(self, the_id: str):
+    def getShortcutById(self, id: str):
         """ Returns the shortcut with the specified id. """
-        if the_id not in self._shortcuts:
-            self.logger().error("Shortcut {} is not defined".format(the_id))
+        if id not in self._shortcuts:
+            self._logger.error("Shortcut {} is not defined".format(id))
             return NullShortcut()
-        return self._shortcuts[the_id]
+        return self._shortcuts[id]
 
     def getPluginByName(self, name: str, type: str) -> AbstractPlugin:
         return self.plugins().plugin(name, type)
