@@ -16,12 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from dpp.ui.widget.search_field import SearchField
-from .shortcut_table import KeyboardShortcutTable
-from dpp.ui.widget.spacer import Spacer
-from dpp.ui.widget.spacer import VSpacer
-from dpp.ui.widget.spacer import HSpacer
-from .tab_bar import TabBar
+from dpp.ui.widget.shortcut_table import KeyboardShortcutTable
+from dpp.ui.widget.spacers import Spacer, VSpacer, HSpacer
+from dpp.ui.widget.tab_bar import TabBar
 from dpp.ui.widget.icon_label import IconLabel
-from .codec_tab import CodecTab
-from .main_window_widget import MainWindowWidget
-from .main_window import MainWindow
